@@ -1,11 +1,13 @@
 import logging
+import re
 
 from django import template
-from django.core.urlresolvers import reverse
 from django.core.cache import cache
+from django.core.files.images import get_image_dimensions
+from django.core.urlresolvers import reverse
 from django.template import Node
 from django.utils.safestring import mark_safe
-from django.utils.html import escape
+from django.utils.html import escape, strip_tags
 from sorl.thumbnail.base import ThumbnailException
 
 from ..crowdsourcing.models import (
@@ -81,11 +83,12 @@ def select_filter(wrapper_format, key, label, value, choices, blank=True):
     if blank:
         html.append('<option value="">---------</option>')
     for choice in choices:
-        value = display = choice
+        option_value = display = choice
         if hasattr(choice, "__iter__"):
-            value, display = choice[0], choice[1]
-        html.append('<option value="%s"' % value)
-        if value == u"%s" % value:
+            option_value, display = choice[0], choice[1]
+        option_value, display = strip_tags(option_value), strip_tags(display)
+        html.append('<option value="%s"' % option_value)
+        if value == u"%s" % option_value:
             html.append('selected="selected"')
         html.append('>%s</option>' % display)
     html.append('</select>')
@@ -160,8 +163,9 @@ register.simple_tag(filters_as_ul)
     
 
 def yahoo_pie_chart(display, question, request_get):
-    survey = display.get_report().survey
-    aggregate = AggregateResultCount(survey, question, request_get)
+    report = display.get_report()
+    survey = report.survey
+    aggregate = AggregateResultCount(survey, question, request_get, report)
     if not aggregate.answer_values:
         return ""
     fieldname = question.fieldname
@@ -210,20 +214,29 @@ def _yahoo_bar_line_chart_helper(display, request_get, chart_type):
                    "this survey.") % display.x_axis_fieldname
         return issue(message)
     single_count = False
+    report = display.get_report()
     if display.aggregate_type in [SATC.DEFAULT, SATC.SUM]:
         aggregate_function = "Sum"
-        aggregate = AggregateResultSum(y_axes, x_axis, request_get)
+        aggregate = AggregateResultSum(y_axes, x_axis, request_get, report)
     elif display.aggregate_type == SATC.AVERAGE:
         aggregate_function = "Average"
-        aggregate = AggregateResultAverage(y_axes, x_axis, request_get)
+        aggregate = AggregateResultAverage(y_axes, x_axis, request_get, report)
     elif display.aggregate_type == SATC.COUNT:
         aggregate_function = "Count"
         if y_axes:
-            aggregate = AggregateResult2AxisCount(y_axes, x_axis, request_get)
+            aggregate = AggregateResult2AxisCount(
+                y_axes,
+                x_axis,
+                request_get,
+                report)
         else:
             single_count = True
             survey = x_axis.survey
-            aggregate = AggregateResultCount(survey, x_axis, request_get)
+            aggregate = AggregateResultCount(
+                survey,
+                x_axis,
+                request_get,
+                report)
     if not aggregate.answer_values:
         return ""
     answer_string = aggregate.yahoo_answer_string
@@ -312,21 +325,15 @@ def _yahoo_chart(display, unique_id, args):
     return mark_safe("\n".join(out))
 
 
-def google_map(display, question, ids):
-    map_id = "map_%d" % question.id
+def google_map(display, question, report):
+    map_id = "map_%d" % display.order
     detail_id = "map_detail_%d" % question.id
-    view = "location_question_results"
-    kwargs = {"question_id": question.pk}
-    if ids:
-        view = "location_question_results_ids"
-        kwargs["submission_ids"] = ids
-        if display.limit_map_answers:
-            split = ids.split(",")[:display.limit_map_answers]
-            kwargs["submission_ids"] = ",".join(split)
-    elif display.limit_map_answers:
-        view = "location_question_results_limit"
-        kwargs["limit_map_answers"] = display.limit_map_answers
-    data_url = reverse(view, kwargs=kwargs)
+    data_url = reverse(
+        "location_question_results",
+        kwargs={
+            "question_id": question.pk,
+            "limit_map_answers": display.limit_map_answers or "",
+            "survey_report_slug": report.slug})
     img = '<img class="loading" src="/media/img/loading.gif" alt="loading" />'
     lat = number_to_javascript(display.map_center_latitude)
     lng = number_to_javascript(display.map_center_longitude)
@@ -427,24 +434,27 @@ def submission_fields(submission,
             out.append('<div class="field">')
             out.append('<label>%s</label>: ' % question.label)
             if answer.image_answer:
+                valid = True
                 try:
                     thmb = answer.image_answer.thumbnail.absolute_url
                     args = (thmb, answer.id,)
                     out.append('<img src="%s" id="img_%d" />' % args)
-                    # This extra hidden input is in case you want to enlarge
-                    # images. Don't bother enlarging images unless we'll
-                    # increase their dimensions by at least 10%.
-                    thumb_width = answer.image_answer.thumbnail.width()
-                    if float(answer.image_answer.width) / thumb_width > 1.1:
-                        format = ('<input type="hidden" id="img_%d_full_url" '
-                                  'value="%s" class="enlargeable" />')
-                        enlarge = answer.image_answer
-                        enlarge = enlarge.extra_thumbnails["max_enlarge"]
-                        enlarge = enlarge.absolute_url
-                        args = (answer.id, enlarge)
-                        out.append(format % args)
+                    x_y = get_image_dimensions(answer.image_answer.file)
                 except ThumbnailException as ex:
+                    valid = False
                     out.append('<div class="error">%s</div>' % str(ex))
+                thumb_width = Answer.image_answer_thumbnail_meta["size"][0]
+                # This extra hidden input is in case you want to enlarge
+                # images. Don't bother enlarging images unless we'll increase
+                # their dimensions by at least 10%.
+                if valid and x_y and float(x_y[0]) / thumb_width > 1.1:
+                    format = ('<input type="hidden" id="img_%d_full_url" '
+                              'value="%s" class="enlargeable" />')
+                    enlarge = answer.image_answer
+                    enlarge = enlarge.extra_thumbnails["max_enlarge"]
+                    enlarge = enlarge.absolute_url
+                    args = (answer.id, enlarge)
+                    out.append(format % args)
             elif question.option_type == OPTION_TYPE_CHOICES.VIDEO:
                 if oembed_expand:
                     html = video_html(answer.value, video_height, video_width)
