@@ -30,19 +30,8 @@ urlpatterns = patterns(
     url(r'^submission_for_map/(?P<id>\d+)/$',
         submission_for_map),
 
-    url(r'^location_question_results/(?P<question_id>\d+)/ids/(?P<submission_ids>[0-9,]+)/$',
+    url(r'^location_question_results/(?P<question_id>\d+)/(?P<limit_map_answers>\d*)/(?P<survey_report_slug>[-a-z0-9_]*)/$',
         location_question_results,
-        {"limit_map_answers": None},
-        name="location_question_results_ids"),
-
-    url(r'^location_question_results/(?P<question_id>\d+)/limit/(?P<limit_map_answers>\d+)/$',
-        location_question_results,
-        {"submission_ids": None},
-        name="location_question_results_limit"),
-
-    url(r'^location_question_results/(?P<question_id>\d+)/$',
-        location_question_results,
-        {"submission_ids": None, "limit_map_answers": None},
         name="location_question_results"),
 
     url(r'^(?P<slug>[-a-z0-9_]+)/$',
